
############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################


import mraa
import time
from struct import *

I2C_ADDR = 0x3E

class AKI_AQM1248A:
    def __init__(self):
        self.RS = mraa.Gpio(36) #GP_IO14
        self.RS.dir(mraa.DIR_OUT)
        self.RS.write(1)

        self.CS = mraa.Gpio(48) #GP_IO15
        self.CS.dir(mraa.DIR_OUT)
        self.CS.write(1)

        self.SPI = mraa.Spi(5)
        self.SPI.frequency(20000)
        print "Init"
        try:
            from PIL import Image, ImageDraw

            SCREEN_WIDTH = 128
            SCREEN_HEIGHT = 48
            self.buffer = Image.new("1", (SCREEN_WIDTH,SCREEN_HEIGHT), "black") #"white"
            self.draw = ImageDraw.Draw(self.buffer)
        except ImportError:
            raise NoSuchLibraryError('PIL')


    def Write_Command(self,data):
        self.CS.write(0)
        self.RS.write(0)
        self.SPI.write(pack('B',data));
        self.CS.write(1)
        self.RS.write(1)
        #time.sleep(0.02)
        #print "Command"
    def Write_Data(self,data):
        self.CS.write(0)
        self.RS.write(1)
        self.SPI.write(pack("B",data));
        self.CS.write(1)
        self.RS.write(1)
        #time.sleep(0.0002)
        #print "Data"
    def SetUp(self):
        self.Write_Command(0xAE)
        self.Write_Command(0xA0)
        self.Write_Command(0xC8)
        self.Write_Command(0xA3)
        self.Write_Command(0x2C)
        time.sleep(0.002)
        self.Write_Command(0x2E)
        time.sleep(0.002)
        self.Write_Command(0x2F)
        time.sleep(0.002)
        self.Write_Command(0x23)
        self.Write_Command(0x81)
        self.Write_Command(0x1C)
        self.Write_Command(0xA4)
        self.Write_Command(0x40)
        self.Write_Command(0xA6)
        self.Write_Command(0xAF)
    def Page(self,page):
        self.Write_Command( 0xB0 | (page & 0x0F))
    def Column(self,col):
        self.Write_Command(0x10 | ((col >> 4) & 0x0F))
        self.Write_Command(0x00 | (col & 0x0F))
    def Line(self,line):
        self.Write_Command(0x40 | (line & 0x0F))
    
    def Clear(self):
        for i in range(8+1):
            self.Page(i)
            self.Column(0)
            for j in range(128):
                self.Write_Data(0)
    
    def Test(self):
        for i in range(6):
            self.Page(i)
            self.Column(0)
            for j in range(128):
                self.Write_Data(0x80)
    def Pixel_Check(self,x,y):
        if(self.buffer.getpixel((x,y)) > 127):
            return 1
        else :
            return 0

    def Uplode(self):
        for i in range(6):
            self.Page(i)
            self.Column(0)
            for j in range(128):
                #print i,j,((0+(8*i))<<0)
                data = 0
                data = data | self.Pixel_Check(j,(0+(8*i)))<<0
                data = data | self.Pixel_Check(j,(1+(8*i)))<<1
                data = data | self.Pixel_Check(j,(2+(8*i)))<<2
                data = data | self.Pixel_Check(j,(3+(8*i)))<<3
                data = data | self.Pixel_Check(j,(4+(8*i)))<<4
                data = data | self.Pixel_Check(j,(5+(8*i)))<<5
                data = data | self.Pixel_Check(j,(6+(8*i)))<<6
                data = data | self.Pixel_Check(j,(7+(8*i)))<<7
                self.Write_Data(data)   
                #print data ,
            #print ""
        #self.buffer.save("img.png", "PNG")     






#import mraa

import smbus
import time

I2C_ADDR = 0x68

class AKI_I2C_MCP3425:

    def __init__(self,i2caddr):
        print "AKI_I2C_MCP3425"
        self.i2c = smbus.SMBus(1)

    def i2cReg(self,wr,addr=0x00,data=0x00):
        try:
            if(wr == "w"):
                #time.sleep(0.1)
                #print "W:0x%02X = 0x%04X" % (addr,data)
                #return self.i2c.writeReg(addr,data)
                return self.i2c.write_byte(I2C_ADDR,data)
            elif(wr == "r"):
                #return self.i2c.readReg(addr)
                ad1 = self.i2c.read_word_data(I2C_ADDR,addr)
                time.sleep(0.1)
                #print "0x%04X" % (ad1)
                return (ad1)

            else :
                return -1
        except IOError, err:
            print "No ACK!"
            time.sleep(0.1)
            self.i2cReg(wr,addr,data)
            
##########################################################################

    def AD_Init(self):
        print "Init"
        return self.i2cReg("w",0x00,0x80)
    def AD_Read(self):
        ad = 0.00001
        #self.i2cReg("w",0x00,0x80)
        ad = self.i2cReg("r",0x88)
        ad = ((ad&0x00ff)<<8) | ((ad&0xff00)>>8)
        #print "0x%04X " % ad

        if(ad & 0x8000 == 0x8000):
            return float(-((ad-1)^0xFFFF)) * 0.0625
        else :
            return float(ad) * 0.001 * 0.0625



# -*- coding: utf-8 -*-

############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################

import time
import RPi.GPIO as GPIO

class AKI_SC1602BSLB:
    def __init__(self,RS,E,D4,D5,D6,D7):
        self.RS = RS
        self.E = E
        self.D4 = D4
        self.D5 = D5
        self.D6 = D6
        self.D7 = D7
        GPIO.setwarnings(False) 
        GPIO.setmode( GPIO.BCM )
        GPIO.setup(self.RS, GPIO.OUT)
        GPIO.setup(self.E, GPIO.OUT)
        GPIO.setup(self.D4, GPIO.OUT)
        GPIO.setup(self.D5, GPIO.OUT)
        GPIO.setup(self.D6, GPIO.OUT)
        GPIO.setup(self.D7, GPIO.OUT)
    def LCD_bitwrite(self,rs,data):   
        GPIO.output(self.RS, rs)
        GPIO.output(self.D7, (data&0x08)>>3 )
        GPIO.output(self.D6, (data&0x04)>>2 )
        GPIO.output(self.D5, (data&0x02)>>1 )
        GPIO.output(self.D4, (data&0x01)>>0 )

        GPIO.output(self.E, 1)
        time.sleep(0.01)
        GPIO.output(self.E, 0)
        time.sleep(0.01)

        GPIO.output(self.D7,0)
        GPIO.output(self.D6,0)
        GPIO.output(self.D5,0)
        GPIO.output(self.D4,0)
        
    def LCD_Write(self,rs,data):   
        self.LCD_bitwrite(rs, (data&0xf0)>>4)
        self.LCD_bitwrite(rs, (data&0x0f))
        time.sleep(0.1)


    def LCD_Init(self):
        self.LCD_bitwrite(0,0x03);
        time.sleep(0.1)
        self.LCD_bitwrite(0,0x03);
        time.sleep(0.1)
        self.LCD_bitwrite(0,0x03);
        time.sleep(0.1)
        self.LCD_bitwrite(0,0x02);
        time.sleep(0.1)
        rLCD_Display_Cmd = 0x08;
        
        self.LCD_Write(0,0x28);     #ファンクションセット　DL = 0; N = 1; F = 0;
        time.sleep(0.1)
        self.LCD_Write(0,0x0E);     #表示コントロール D = 0; C = 0; B = 0;
        time.sleep(0.1)
        self.LCD_Write(0,0x01);     #表示クリア
        time.sleep(0.1)
        self.LCD_Write(0,0x06);     #エントリーモードセット　l/D = 0; S = 0;
        time.sleep(0.1)
    def DisplayON(self):
        self.LCD_Write(0,0x0F);

    def ClearDisplay(self):
        # "Clear Display"
        self.LCD_Write(0,0x01);
        self.LCD_Write(0,0x02);

    def WritePos(self,Row,Col):        
        if(Row == 0) :
            Row = 0x00
        elif(Row == 1) :
            Row = 0x40
        elif(Row == 2) :
            Row = 0x14
        elif(Row == 3) :
            Row = 0x54

        if(Row == 2 or Row == 3 ) :
            Col = Col | 0x04
        self.LCD_Write( 0 , 0x80 | Col | Row);

    def WriteChar(self,c):
        self.LCD_Write(1,ord(c))

    def WriteStr(self,s,t=0):
        for c in s :        
            self.LCD_Write(1,ord(c))
            time.sleep(t)

    def NewClearDisplay(self,pos,time):
        self.WritePos(pos,0)
        self.WriteStr("                ",time)
        # "Clear Display"







############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################


import platform

plat = platform.platform()

#-----------------------------------------#
# Intel Edison platform
#-----------------------------------------#
if "edison" in plat :
    #print "Platform is Edison "
    from edison.test import test
    from edison.AKI_I2C_HDC1000 import AKI_I2C_HDC1000
    from edison.AKI_I2C_L3GD20 import AKI_I2C_L3GD20
    from edison.AKI_I2C_LPS25H import AKI_I2C_LPS25H
    from edison.AKI_I2C_LIS3DH import AKI_I2C_LIS3DH
    from edison.AKI_I2C_OLED import AKI_I2C_OLED
    from edison.AKI_I2C_MCP23017 import AKI_I2C_MCP23017
    from edison.AKI_I2C_SO1602AWYB import AKI_I2C_SO1602AWYB
    from edison.AKI_I2C_S11059 import AKI_I2C_S11059
    from edison.AKI_I2C_AQM0802A import AKI_I2C_AQM0802A
    from edison.AKI_SPI_AQM1248A import AKI_SPI_AQM1248A
    from edison.AKI_GPIO_SG12864ASLB import AKI_GPIO_SG12864ASLB

#-----------------------------------------#
# Raspberry Pi platform
#-----------------------------------------#
if  ("armv7l" or "armv6l")  in plat :
    #print "Platform is RaspberryPi "
    from raspberrypi.AKI_I2C_MCP3425 import AKI_I2C_MCP3425
    from raspberrypi.AKI_I2C_LPS25H import AKI_I2C_LPS25H
    from raspberrypi.AKI_I2C_HDC1000 import AKI_I2C_HDC1000
    from raspberrypi.AKI_I2C_AQM1602A import AKI_I2C_AQM1602A
    from raspberrypi.AKI_I2C_ACM1602N1 import AKI_I2C_ACM1602N1
    from raspberrypi.AKI_I2C_ADT7410 import AKI_I2C_ADT7410
    #from raspberrypi.AKI_GPIO_SC1602BSLB import AKI_GPIO_SC1602BSLB
    from raspberrypi.AKI_I2C_S11059 import AKI_I2C_S11059




############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################


import mraa
import time
from struct import *



class AKI_I2C_BM280:
    def __init__(self,addr):
        I2C_PORT = 6
        self.I2C_ADDR = addr
        self.i2c = mraa.I2c(I2C_PORT)
        self.i2c.address(self.I2C_ADDR)

    def i2cReg(self,wr,addr,data=0x00):
        if(wr == "w"):
            print "W:0x%02X = 0x%02X" % (addr,data)
            return self.i2c.writeReg(addr,data)
        elif(wr == "r"):
            #self.i2c.writeReg(addr,data)
            tmp = self.i2c.readReg(addr)
            print "R:0x%02X = 0x%02X" % (addr,tmp)
            return tmp
        else :
            return -1



############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################


import smbus
import time
from struct import *

class AKI_I2C_S11059:
    def __init__(self,I2C_PORT):
        self.I2C_ADDR = 0x2A
        self.i2c = smbus.SMBus(1)

    def i2cReg(self,wr,addr,data=0x00):
        if(wr == "w"):
            return  self.i2c.write_byte_data(self.I2C_ADDR,addr,data)
        elif(wr == "r"):
            return self.i2c.read_byte_data(self.I2C_ADDR,addr)
        else :
            return -1
    def Init(self):
        #-- Init --#
        self.i2cReg("w",0x00,0x89)
        self.i2cReg("w",0x00,0x09)
    def RED(self):
        return self.i2cReg("r",0x03)<<8 | self.i2cReg("r",0x04)
    def GREEN(self):
        return self.i2cReg("r",0x05)<<8 | self.i2cReg("r",0x06)
    def BLUE(self):
        return self.i2cReg("r",0x07)<<8 | self.i2cReg("r",0x08)
    def IR(self):
        return self.i2cReg("r",0x09)<<8 | self.i2cReg("r",0x0A)

    def RGBISens(self):
        #-- Red Color --#
        r = self.i2cReg("r",0x03)<<8 | self.i2cReg("r",0x04)
        #-- Green Color --#
        g = self.i2cReg("r",0x05)<<8 | self.i2cReg("r",0x06)
        #-- Blue Color --#
        b = self.i2cReg("r",0x07)<<8 | self.i2cReg("r",0x08)
        #-- Ir Data --#
        ir = self.i2cReg("r",0x09)<<8 | self.i2cReg("r",0x0A)
        return (r,g,b,ir)




############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################

import mraa
import time
from struct import *


I2C_PORT = 6
I2C_ADDR = 0x20

class MCP23017:

    def __init__(self):
        print "MCP23017 Open."
        i2c = mraa.I2c(I2C_PORT)
        i2c.address(I2C_ADDR)

    def i2cReg(self,wr,addr,data):
        if(wr == "w"):
            return i2c.writeReg(addr,data)
        elif(wr == "r"):
            return i2c.readReg(addr)
        else :
            return -1

    def IODIRA(self,wr,data):       
        return i2cReg(wr,0x00,data);
    def IPOLA(self,wr,data):        
        return i2cReg(wr,0x02,data);
    def GPINTENA(self,wr,data):     
        return i2cReg(wr,0x04,data);
    def DEFVALA(self,wr,data):      
        return i2cReg(wr,0x06,data);
    def INTCONA(self,wr,data):      
        return i2cReg(wr,0x08,data);
    def IOCONA(self,wr,data):       
        return i2cReg(wr,0x0A,data);
    def GPPUA(self,wr,data):        
        return i2cReg(wr,0x0C,data);
    def INTFA(self,wr,data):        
        return i2cReg(wr,0x0E,data);
    def INTCAPA(self,wr,data):      
        return i2cReg(wr,0x10,data);
    def GPIOA(self,wr,data):        
        return i2cReg(wr,0x12,data);
    def OLATA(self,wr,data):        
        return i2cReg(wr,0x14,data);

    def IODIRB(self,wr,data):       
        return i2cReg(wr,0x01,data);
    def IPOLB(self,wr,data):        
        return i2cReg(wr,0x03,data);
    def GPINTENB(self,wr,data):     
        return i2cReg(wr,0x05,data);
    def DEFVALB(self,wr,data):      
        return i2cReg(wr,0x07,data);
    def INTCONB(self,wr,data):      
        return i2cReg(wr,0x09,data);
    def IOCONA(self,wr,data):       
        return i2cReg(wr,0x0B,data);
    def GPPUB(self,wr,data):        
        return i2cReg(wr,0x0D,data);
    def INTFB(self,wr,data):        
        return i2cReg(wr,0x0F,data);
    def INTCAPB(self,wr,data):      
        return i2cReg(wr,0x11,data);
    def GPIOB(self,wr,data):        
        return i2cReg(wr,0x13,data);
    def OLATB(self,wr,data):        
        return i2cReg(wr,0x15,data);




# -*- coding: utf-8 -*-

############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################

import time
import mraa


class AKI_GPIO_SC1602BSLB:
    def __init__(self,RS,E,D4,D5,D6,D7):
        self.RS = mraa.Gpio(RS)
        self.E = mraa.Gpio(E)
        self.D4 = mraa.Gpio(D4)
        self.D5 = mraa.Gpio(D5)
        self.D6 = mraa.Gpio(D6)
        self.D7 = mraa.Gpio(D7)       
        self.RS.dir(mraa.DIR_OUT)
        self.E.dir(mraa.DIR_OUT)
        self.D4.dir(mraa.DIR_OUT)
        self.D5.dir(mraa.DIR_OUT)
        self.D6.dir(mraa.DIR_OUT)
        self.D7.dir(mraa.DIR_OUT)

    def LCD_bitwrite(self,rs,data):   
        self.RS.write(rs)
        self.D7.write((data&0x08)>>3 )
        self.D6.write((data&0x04)>>2 )
        self.D5.write((data&0x02)>>1 )
        self.D4.write((data&0x01)>>0 )

        self.E.write(1)
        time.sleep(0.01)
        self.E.write(0)
        time.sleep(0.01)

        self.D7.write(0)
        self.D6.write(0)
        self.D5.write(0)
        self.D4.write(0)
        
    def LCD_Write(self,rs,data):   
        self.LCD_bitwrite(rs, (data&0xf0)>>4)
        self.LCD_bitwrite(rs, (data&0x0f))
        #time.sleep(0.1)


    def LCD_Init(self):
        self.LCD_bitwrite(0,0x03);
        time.sleep(0.1)
        self.LCD_bitwrite(0,0x03);
        time.sleep(0.1)
        self.LCD_bitwrite(0,0x03);
        time.sleep(0.1)
        self.LCD_bitwrite(0,0x02);
        time.sleep(0.1)
        rLCD_Display_Cmd = 0x08;
        
        self.LCD_Write(0,0x28);     #ファンクションセット　DL = 0; N = 1; F = 0;
        time.sleep(0.1)
        self.LCD_Write(0,0x0E);     #表示コントロール D = 0; C = 0; B = 0;
        time.sleep(0.1)
        self.LCD_Write(0,0x01);     #表示クリア
        time.sleep(0.1)
        self.LCD_Write(0,0x06);     #エントリーモードセット　l/D = 0; S = 0;
        time.sleep(0.1)
    def DisplayON(self):
        self.LCD_Write(0,0x0F);

    def ClearDisplay(self):
        # "Clear Display"
        self.LCD_Write(0,0x01);
        self.LCD_Write(0,0x02);

    def WritePos(self,Row,Col):        
        if(Row == 0) :
            Row = 0x00
        elif(Row == 1) :
            Row = 0x40
        elif(Row == 2) :
            Row = 0x14
        elif(Row == 3) :
            Row = 0x54

        if(Row == 2 or Row == 3 ) :
            Col = Col | 0x04
        self.LCD_Write( 0 , 0x80 | Col | Row);

    def WriteChar(self,c):
        self.LCD_Write(1,ord(c))

    def WriteStr(self,s,t=0):
        for c in s :        
            self.LCD_Write(1,ord(c))
            time.sleep(t)

    def NewClearDisplay(self,pos,time):
        self.WritePos(pos,0)
        self.WriteStr("                ",time)
        # "Clear Display"







############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################

import mraa
import time
from struct import *


class AKI_I2C_SO1602AWYB:
    def __init__(self,port):
        I2C_PORT = port
        I2C_ADDR = 0x3C
        self.i2c = mraa.I2c(I2C_PORT)  
        self.i2c.address(I2C_ADDR)
    
    def Init_OLED(self):
        # "Clear Display"
        self.i2c.writeReg(0x00,0x01)
        time.sleep(0.20)
        # "Return Home"
        self.i2c.writeReg(0x00,0x02)
        time.sleep(0.002)
        # "Display ON!"
        self.i2c.writeReg(0x00,0x0F)
        time.sleep(0.002)
        # "Clear Display"
        self.i2c.writeReg(0x00,0x01)
        time.sleep(0.02)
        # "Light Display"
        self.i2c.writeReg(0x00,0x2a)
        self.i2c.writeReg(0x00,0x79)
        self.i2c.writeReg(0x00,0xFF)
        self.i2c.writeReg(0x00,0x78)
        self.i2c.writeReg(0x00,0x28)


    def ClearDisplay(self):
        # "Clear Display"
        self.i2c.writeReg(0x00,0x01)

    def WritePos(self,a,b):     
        if a ==0:
            self.i2c.writeReg(0x00,0x80|b)
        elif a ==1:
            self.i2c.writeReg(0x00,0x80|0x20|b)

    def WriteChar(self,c,t=20):
        self.i2c.writeReg(0x40,c )
        time.sleep(t/100.0)

    def WriteStr(self,s,t=20):
        #print s
        for c in s :        
            #print ord(c)
            self.i2c.writeReg(0x40,ord(c))
            time.sleep(t/100.0)

    def NewClearDisplay(self,pos,time):
        self.WritePos(pos,0)
        self.WriteStr("                ",time)
        # "Clear Display"








############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################

import mraa
import time
from struct import *



class AKI_SG12864ASLB:
    def __init__(self):
        self.HI = 0     # NOT LogicIC
        self.LOW = 1    # NOT LogicIC

        self.DI = mraa.Gpio(21) #GP_IO183
        self.RW = mraa.Gpio(0) #GP_IO182
        self.E = mraa.Gpio(14) #GP_IO13
        self.DB0 = mraa.Gpio(20) #GP_IO12
        self.DB1 = mraa.Gpio(36) #GP_IO14
        self.DB2 = mraa.Gpio(48) #GP_IO15
        self.DB3 = mraa.Gpio(47) #GP_IO49
        self.DB4 = mraa.Gpio(33) #GP_IO48
        self.DB5 = mraa.Gpio(46) #GP_IO47
        self.DB6 = mraa.Gpio(32) #GP_IO46
        self.DB7 = mraa.Gpio(45) #GP_IO45
        self.CS1 = mraa.Gpio(15) #GP_IO165
        self.CS2 = mraa.Gpio(31) #GP_IO44
        self.DI.dir(mraa.DIR_OUT)
        self.RW.dir(mraa.DIR_OUT)
        self.E.dir(mraa.DIR_OUT)
        self.DB0.dir(mraa.DIR_OUT)
        self.DB1.dir(mraa.DIR_OUT)
        self.DB2.dir(mraa.DIR_OUT)
        self.DB3.dir(mraa.DIR_OUT)
        self.DB4.dir(mraa.DIR_OUT)
        self.DB5.dir(mraa.DIR_OUT)
        self.DB6.dir(mraa.DIR_OUT)
        self.DB7.dir(mraa.DIR_OUT)
        self.CS1.dir(mraa.DIR_OUT)
        self.CS2.dir(mraa.DIR_OUT)

        self.DI.write(self.LOW)
        self.RW.write(self.LOW)
        self.E.write(self.LOW)
        self.DB0.write(self.LOW)
        self.DB1.write(self.LOW)
        self.DB2.write(self.LOW)
        self.DB3.write(self.LOW)
        self.DB4.write(self.LOW)
        self.DB5.write(self.LOW)
        self.DB6.write(self.LOW)
        self.DB7.write(self.LOW)
        self.CS1.write(self.LOW)
        self.CS2.write(self.LOW)
        #time.sleep(0.01)
        self.RW.write(self.HI)
        #time.sleep(0.01)   

        print "Init"
        try:
            from PIL import Image, ImageDraw

            SCREEN_WIDTH = 128
            SCREEN_HEIGHT = 64
            self.buffer = Image.new("1", (SCREEN_WIDTH,SCREEN_HEIGHT), "black") #"white"
            self.draw = ImageDraw.Draw(self.buffer)
        except ImportError:
            raise NoSuchLibraryError('PIL')

    def Write_Command(self,data,cs):
        data = ~ data   # NOT LogicIC
        self.DI.write(self.LOW)
        #self.RW.write(self.HI)
        self.DB0.write((data&0x01)>>0)
        self.DB1.write((data&0x02)>>1)
        self.DB2.write((data&0x04)>>2)
        self.DB3.write((data&0x08)>>3)
        self.DB4.write((data&0x10)>>4)
        self.DB5.write((data&0x20)>>5)
        self.DB6.write((data&0x40)>>6)
        self.DB7.write((data&0x80)>>7)
        if (cs == 0):
            self.CS1.write(self.HI)
            self.CS2.write(self.LOW)
        else :
            self.CS1.write(self.LOW)
            self.CS2.write(self.HI)
        self.E.write(self.LOW)
        self.E.write(self.HI)
        self.E.write(self.LOW)
        #time.sleep(0.0001)     
        

    def Write_Data(self,data,cs):
        data = ~ data   # NOT LogicIC
        self.DI.write(self.HI)
        #self.RW.write(self.LOW)
        self.E.write(self.LOW)
        self.DB0.write((data&0x01)>>0)
        self.DB1.write((data&0x02)>>1)
        self.DB2.write((data&0x04)>>2)
        self.DB3.write((data&0x08)>>3)
        self.DB4.write((data&0x10)>>4)
        self.DB5.write((data&0x20)>>5)
        self.DB6.write((data&0x40)>>6)
        self.DB7.write((data&0x80)>>7)
        if (cs == 0):
            self.CS1.write(self.HI)
            self.CS2.write(self.LOW)
        else :
            self.CS1.write(self.LOW)
            self.CS2.write(self.HI)
        self.E.write(self.LOW)
        self.E.write(self.HI)
        self.E.write(self.LOW)
        #time.sleep(0.0001)     
        
    def SetUp(self):
        self.Write_Command(0xC0,0)
        self.Write_Command(0x3F,0)
        self.Write_Command(0xC0,1)
        self.Write_Command(0x3F,1)

    def SetPosData(self,x,y,deta):
        if( x < 64 ):
            self.Write_Command(0x40 | (x & 0x3F),0)
            self.Write_Command(0xB8 | (y & 0x07),0)
            self.Write_Data(deta,0)
        else    :
            self.Write_Command(0x40 | (x & 0x3F),1)
            self.Write_Command(0xB8 | (y & 0x07),1)
            self.Write_Data(deta,1)

    def Clear(self):
        for y in range(8):
            for x in range(128):
                self.SetPosData(x,y,0x00)

    def Test(self):
        for y in range(8):
            for x in range(128):
                self.SetPosData(x,y,0x0F)

    def Pixel_Check(self,x,y):
        if(self.buffer.getpixel((x,y)) > 127):
            return 1
        else :
            return 0

    def Uplode(self):
        for y in range(8):
            for x in range(128):
                #print i,j,((0+(8*i))<<0)
                data = 0
                data = data | self.Pixel_Check(x,(0+(8*y)))<<0
                data = data | self.Pixel_Check(x,(1+(8*y)))<<1
                data = data | self.Pixel_Check(x,(2+(8*y)))<<2
                data = data | self.Pixel_Check(x,(3+(8*y)))<<3
                data = data | self.Pixel_Check(x,(4+(8*y)))<<4
                data = data | self.Pixel_Check(x,(5+(8*y)))<<5
                data = data | self.Pixel_Check(x,(6+(8*y)))<<6
                data = data | self.Pixel_Check(x,(7+(8*y)))<<7
                self.SetPosData(x,y,data)
                #print data ,
            #print ""
        self.buffer.save("img.png", "PNG")      








#import mraa

import smbus
import time

I2C_ADDR = 0x50

class AKI_I2C_ACM1602N1:
    def __init__(self):
        print "AKI_I2C_ACM1602N1"
        self.i2c = smbus.SMBus(1)
    def i2cReg(self,wr,addr,data):
        try:
            if(wr == "w"):
                #time.sleep(0.1)
                #print "W:0x%02X = 0x%04X" % (addr,data)
                #return self.i2c.writeReg(addr,data)
                return self.i2c.write_byte_data(I2C_ADDR,addr,data)
            elif(wr == "r"):
                #return self.i2c.readReg(addr)
                return self.i2c.read_byte(I2C_ADDR,addr)
            else :
                return -1
        except IOError, err:
            print "No ACK!"
            time.sleep(0.1)
            self.i2cReg(wr,addr,data)
    def Init_LCD(self):
        # "Clear Display"
        self.i2cReg("w",0x00,0x01)
        time.sleep(0.20)
        # "Function set"
        self.i2cReg("w",0x00,0x38)
        time.sleep(0.1)
        # "Clear Display"
        self.i2cReg("w",0x00,0x01)
        time.sleep(0.20)
        # "Display ON!"
        self.i2cReg("w",0x00,0x0C)
        time.sleep(1)

    def ClearDisplay(self):
        # "Clear Display"
        self.i2cReg("w",0x00,0x01)
        #time.sleep(0.1)

    def WritePos(self,a,b):        
        if a ==0:
            self.i2cReg("w",0x00,0x80|b)
        elif a ==1:
            self.i2cReg("w",0x00,0x80|0x40|b)
        #time.sleep(0.3)

    def WriteChar(self,c):
        self.i2cReg("w",0x80,c )

    def WriteStr(self,s,t=0):
        #print s
        for c in s :        
            #print ord(c)
            self.i2cReg("w",0x80,ord(c))
            time.sleep(t)

    def NewClearDisplay(self,pos,time):
        self.WritePos(pos,0)
        self.WriteStr("                ",time)
        # "Clear Display"







import mraa
import time
from struct import *

I2C_ADDR = 0x3C

class AKI_I2C_OLED:
	def __init__(self):
		self.i2c = mraa.I2c(6)	
		self.i2c.address(I2C_ADDR)
	
	def Init_OLED(self):
		# "Clear Display"
		self.i2c.writeReg(0x00,0x01)
		time.sleep(0.20)
		# "Return Home"
		self.i2c.writeReg(0x00,0x02)
		time.sleep(0.002)
		# "Display ON!"
		self.i2c.writeReg(0x00,0x0F)
		time.sleep(0.002)
		# "Clear Display"
		self.i2c.writeReg(0x00,0x01)
		time.sleep(0.02)
		# "Light Display"
		self.i2c.writeReg(0x00,0x2a)
		self.i2c.writeReg(0x00,0x79)
		self.i2c.writeReg(0x00,0xFF)
		self.i2c.writeReg(0x00,0x78)
		self.i2c.writeReg(0x00,0x28)


	def ClearDisplay(self):
		# "Clear Display"
		self.i2c.writeReg(0x00,0x01)

	def WritePos(self,a,b):		
		if a ==0:
			self.i2c.writeReg(0x00,0x80|b)
		elif a ==1:
			self.i2c.writeReg(0x00,0x80|0x20|b)

	def WriteChar(self,c,t=20):
		self.i2c.writeReg(0x40,c )
		time.sleep(t/100.0)

	def WriteStr(self,s,t=20):
		#print s
		for c in s :		
			#print ord(c)
			self.i2c.writeReg(0x40,ord(c))
			time.sleep(t/200.0)

	def NewClearDisplay(self,pos,time):
		self.WritePos(pos,0)
		self.WriteStr("                ",time)
		# "Clear Display"







import smbus
import time

I2C_ADDR = 0x3e
class AKI_I2C_AQM0802A:
    def __init__(self):
        print "AKI_I2C_AQM0802A"
        self.i2c = smbus.SMBus(1)
    def i2cReg(self,wr,addr,data):
        try:
            if(wr == "w"):
                return self.i2c.write_byte_data(I2C_ADDR,addr,data)
            elif(wr == "r"):
                return self.i2c.read_byte(I2C_ADDR,addr)
            else :
                return -1
        except IOError, err:
            print "No ACK!"
            exit()
    def Init_LCD(self):
        # "Function set"
        self.i2cReg("w",0x00,0x38)
        time.sleep(0.10)
        # "Function set"
        self.i2cReg("w",0x00,0x39)
        time.sleep(0.10)
        # "Internal OSC frequency"
        self.i2cReg("w",0x00,0x14)
        time.sleep(0.10)
        # "Contrast Set"
        self.i2cReg("w",0x00,0x70)
        time.sleep(0.10)
        # "Power/ICON Set"
        self.i2cReg("w",0x00,0x56)
        time.sleep(0.10)
        # "Follower control"
        self.i2cReg("w",0x00,0x6c)
        time.sleep(0.10)
        # "Function set"
        self.i2cReg("w",0x00,0x38)
        time.sleep(0.10)
        # "Display ON/OFF"
        self.i2cReg("w",0x00,0x0c)
        time.sleep(0.10)


    def ClearDisplay(self):
        # "Clear Display"
        self.i2cReg("w",0x00,0x01)
        #time.sleep(0.1)

    def WritePos(self,a,b):        
        if a ==0:
            self.i2cReg("w",0x00,0x80|b)
        elif a ==1:
            self.i2cReg("w",0x00,0x80|0x40|b)
        #time.sleep(0.3)

    def WriteChar(self,c):
        self.i2cReg("w",0x40,c )
	time.sleep(0.3)

    def WriteStr(self,s,t=0):
        #print s
        for c in s :        
            #print ord(c)
            self.i2cReg("w",0x40,ord(c))
            time.sleep(t)

    def NewClearDisplay(self,pos,time):
        self.WritePos(pos,0)
        self.WriteStr("                ",time)
        # "Clear Display"





############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################

import mraa
import time

I2C_ADDR = 0x3E

class AKI_I2C_AQM0802A:
    def __init__(self):
        self.i2c = mraa.I2c(6)  
        self.i2c.frequency(100000)
        self.i2c.address(I2C_ADDR)
        #self.i2c.write(0xff)
    def Init_LCD(self):
        # "Function set"
        self.i2c.writeReg(0x00,0x38)
        time.sleep(0.1)
        # "Function set"
        self.i2c.writeReg(0x00,0x39)
        time.sleep(0.1)
        # "Internal OSC frequency "
        self.i2c.writeReg(0x00,0x14)
        time.sleep(0.1)
        # "Contrast set "
        self.i2c.writeReg(0x00,0x70)
        time.sleep(0.1)
        # "Power/ICON/Contrast control "
        self.i2c.writeReg(0x00,0x56)
        time.sleep(0.1)
        # "Follower control "
        self.i2c.writeReg(0x00,0x6C)
        time.sleep(0.1)

        time.sleep(0.20)
        # "Function set"
        self.i2c.writeReg(0x00,0x38)
        time.sleep(0.1)


        # "Clear Display"
        self.i2c.writeReg(0x00,0x01)
        time.sleep(0.20)
        # "Return Home"
        self.i2c.writeReg(0x00,0x02)
        time.sleep(0.002)
        # "Display ON!"
        self.i2c.writeReg(0x00,0x0C)
        time.sleep(0.002)
        # "Clear Display"
        self.i2c.writeReg(0x00,0x01)
        time.sleep(0.02)
        # "Light Display"
        #self.i2c.writeReg(0x00,0x2a)
        #time.sleep(0.1)
        #self.i2c.writeReg(0x00,0x79)
        #time.sleep(0.1)
        #self.i2c.writeReg(0x00,0xFF)
        #time.sleep(0.1)
        #self.i2c.writeReg(0x00,0x78)
        #time.sleep(0.1)
        #self.i2c.writeReg(0x00,0x28)
        #time.sleep(0.1)


    def ClearDisplay(self):
        # "Clear Display"
        self.i2c.writeReg(0x00,0x01)
        #time.sleep(0.1)

    def WritePos(self,a,b):     
        if a ==0:
            self.i2c.writeReg(0x00,0x80|b)
        elif a ==1:
            self.i2c.writeReg(0x00,0x80|0x40|b)
        #time.sleep(0.3)

    def WriteChar(self,c):
        self.i2c.writeReg(0x40,c )
        #time.sleep(0.3)

    def WriteStr(self,s):
        #print s
        for c in s :        
            #print ord(c)
            self.i2c.writeReg(0x40,ord(c))
            #time.sleep(0.3)

    def NewClearDisplay(self,pos,time):
        self.WritePos(pos,0)
        self.WriteStr("                ",time)
        # "Clear Display"







import mraa
import time
from struct import *



class AKI_GPIO_SG12864ASLB:
	def __init__(self,RS,RW,E,D0,D1,D2,D3,D4,D5,D6,D7,CS1,CS2,Reset):
		self.HI = 1
		self.LOW = 0	
		self.RS = mraa.Gpio(RS) 
		self.RW = mraa.Gpio(RW) 
		self.E = mraa.Gpio(E) 
		self.DB0 = mraa.Gpio(D0)
		self.DB1 = mraa.Gpio(D1)
		self.DB2 = mraa.Gpio(D2) 
		self.DB3 = mraa.Gpio(D3) 
		self.DB4 = mraa.Gpio(D4) 
		self.DB5 = mraa.Gpio(D5) 
		self.DB6 = mraa.Gpio(D6) 
		self.DB7 = mraa.Gpio(D7) 
		self.CS1 = mraa.Gpio(CS1) 
		self.CS2 = mraa.Gpio(CS2) 
		self.Reset = mraa.Gpio(Reset) 

		self.RS.useMmap(True) 
		self.RW.useMmap(True)
		self.E.useMmap(True)
		self.DB0.useMmap(True)
		self.DB1.useMmap(True)
		self.DB3.useMmap(True) 
		self.DB4.useMmap(True)
		self.DB5.useMmap(True) 
		self.DB6.useMmap(True)
		self.DB7.useMmap(True)
		self.CS1.useMmap(True) 
		self.CS2.useMmap(True)
		self.Reset.useMmap(True)
		

		self.RS.dir(mraa.DIR_OUT)
		self.RW.dir(mraa.DIR_OUT)
		self.E.dir(mraa.DIR_OUT)
		self.DB0.dir(mraa.DIR_OUT)
		self.DB1.dir(mraa.DIR_OUT)
		self.DB2.dir(mraa.DIR_OUT)
		self.DB3.dir(mraa.DIR_OUT)
		self.DB4.dir(mraa.DIR_OUT)
		self.DB5.dir(mraa.DIR_OUT)
		self.DB6.dir(mraa.DIR_OUT)
		self.DB7.dir(mraa.DIR_OUT)
		self.CS1.dir(mraa.DIR_OUT)
		self.CS2.dir(mraa.DIR_OUT)
		self.Reset.dir(mraa.DIR_OUT)
		
		self.RS.write(self.LOW)
		self.RW.write(self.LOW)
		self.E.write(self.LOW)
		self.DB0.write(self.LOW)
		self.DB1.write(self.LOW)
		self.DB2.write(self.LOW)
		self.DB3.write(self.LOW)
		self.DB4.write(self.LOW)
		self.DB5.write(self.LOW)
		self.DB6.write(self.LOW)
		self.DB7.write(self.LOW)
		self.CS1.write(self.LOW)
		self.CS2.write(self.LOW)
		self.Reset.write(self.LOW)
 		
 		#time.sleep(0.01)
		self.Reset.write(self.HI)
 		time.sleep(0.01)
		#time.sleep(0.01)	


		print "Init"
		try:
			from PIL import Image, ImageDraw
			self.SCREEN_WIDTH = 128
			self.SCREEN_HEIGHT = 64
			self.buffer = Image.new("1", (self.SCREEN_WIDTH,self.SCREEN_HEIGHT), "white") #
			self.draw = ImageDraw.Draw(self.buffer)
		except ImportError:
			raise NoSuchLibraryError('PIL')
	#===============================================================================#
	def Write_Command(self,data,cs):
		self.RS.write(self.LOW)
		self.DB0.write((data&0x01)>>0)
		self.DB1.write((data&0x02)>>1)
		self.DB2.write((data&0x04)>>2)
		self.DB3.write((data&0x08)>>3)
		self.DB4.write((data&0x10)>>4)
		self.DB5.write((data&0x20)>>5)
		self.DB6.write((data&0x40)>>6)
		self.DB7.write((data&0x80)>>7)
		if (cs == 0):
			self.CS1.write(self.HI)
			self.CS2.write(self.LOW)
		else :
			self.CS1.write(self.LOW)
			self.CS2.write(self.HI)
		self.E.write(self.LOW)
		self.E.write(self.HI)
		self.E.write(self.LOW)
		#time.sleep(0.0001)		
	#===============================================================================#
	def Write_Data(self,data,cs):
		self.RS.write(self.HI)
		self.E.write(self.LOW)
		self.DB0.write((data&0x01)>>0)
		self.DB1.write((data&0x02)>>1)
		self.DB2.write((data&0x04)>>2)
		self.DB3.write((data&0x08)>>3)
		self.DB4.write((data&0x10)>>4)
		self.DB5.write((data&0x20)>>5)
		self.DB6.write((data&0x40)>>6)
		self.DB7.write((data&0x80)>>7)
		if (cs == 0):
			self.CS1.write(self.HI)
			self.CS2.write(self.LOW)
		else :
			self.CS1.write(self.LOW)
			self.CS2.write(self.HI)
		self.E.write(self.LOW)
		self.E.write(self.HI)
		self.E.write(self.LOW)
		#time.sleep(0.0001)		
	#===============================================================================#
	def SetUp(self):
		self.Write_Command(0xC0,0) #Display StartLine 
		self.Write_Command(0x3F,0) #Display ON
		self.Write_Command(0xC0,1) #Display StartLine
		self.Write_Command(0x3F,1) #Display ON

	#===============================================================================#
	def SetPosData(self,x,y,deta):
		if( x < 64 ):
			self.Write_Command(0x40 | (x & 0x3F),0)
			self.Write_Command(0xB8 | (y & 0x07),0)
			self.Write_Data(deta,0)
		else	:
			self.Write_Command(0x40 | (x & 0x3F),1)
			self.Write_Command(0xB8 | (y & 0x07),1)
			self.Write_Data(deta,1)
	#===============================================================================#
	def Clear(self):
		for y in range(8):
			for x in range(128):
				self.SetPosData(x,y,0x00)
		del self.buffer
		del self.draw
		from PIL import Image, ImageDraw
		self.buffer = Image.new("1", (self.SCREEN_WIDTH,self.SCREEN_HEIGHT), "white") #"white"
		self.draw = ImageDraw.Draw(self.buffer)
	#===============================================================================#
	def Test(self):
		for y in range(8):
			for x in range(128):
				self.SetPosData(x,y,0x0F)
	#===============================================================================#
	def Pixel_Check(self,x,y):
		if(self.buffer.getpixel((x,y)) > 127):
			return 1
		else :
			return 0
	#===============================================================================#
	def Uplode(self):
		for y in range(8):
			for x in range(128):
				#print i,j,((0+(8*i))<<0)
				data = 0
				data = data | self.Pixel_Check(x,(0+(8*y)))<<0
				data = data | self.Pixel_Check(x,(1+(8*y)))<<1
				data = data | self.Pixel_Check(x,(2+(8*y)))<<2
				data = data | self.Pixel_Check(x,(3+(8*y)))<<3
				data = data | self.Pixel_Check(x,(4+(8*y)))<<4
				data = data | self.Pixel_Check(x,(5+(8*y)))<<5
				data = data | self.Pixel_Check(x,(6+(8*y)))<<6
				data = data | self.Pixel_Check(x,(7+(8*y)))<<7
				self.SetPosData(x,y,~data)
				#print data ,
			#print ""
		#self.buffer.save("img.png", "PNG")	
		del self.buffer
		del self.draw
		from PIL import Image, ImageDraw
		self.buffer = Image.new("1", (self.SCREEN_WIDTH,self.SCREEN_HEIGHT), "white") #"white"
		self.draw = ImageDraw.Draw(self.buffer)
		
	#===============================================================================#
	def Save(self,filename):
		self.buffer.save(filename, "PNG")	




import smbus 
import time
from struct import *


I2C_PORT = 6
I2C_ADDR = 0x40

class AKI_I2C_HDC1000:
    def __init__(self):
        print "== HDC1000 Open =="          
        print "* I2C Port:%d" % I2C_PORT     
        print "* I2C Addr:0x%2x" % I2C_ADDR     
        print "=" *20
        self.i2c = smbus.SMBus(1)

    def i2cReg(self,wr,addr=0x00,data=0x0000):
        try :
            if(wr == "w"):
                tmp = (data&0x00FF)<<8 | (data&0xFF00)>>8
                #print "W:0x%02X = 0x%04X" % (addr,data)
                return self.i2c.write_word_data(I2C_ADDR,addr,tmp)
            elif(wr == "r"):
                tmp =  self.i2c.read_word_data(I2C_ADDR,addr)
                tmp = (tmp&0x00FF)<<8 | (tmp&0xFF00)>>8               
                #print "R:0x%02X = 0x%04X" % (addr,tmp)
                return tmp
            else :
               return -1
        except IOError, err:
            print "No ACK!"
            time.sleep(0.1)
            self.i2cReg(wr,addr,data)
    def Config(self):
         # 0 - 7 bit = 0
         # 8bit :     HRES1 = 0
         # 9bit :     HRES2 = 0 14bit mode
         # 10bit :     TRES = 0
         # 11bit :     BTST = 0 (ReadOnly)
         # 12bit :     MODE = 0
         # 13bit :     Reserved = 0
         # 14bit :     Reserved = 0
         # 15bit :     RST = 0
         self.i2cReg('r',0xFE)
         self.i2cReg('r',0xFF)
         self.i2cReg('r',0x02)
         self.i2cReg('w',0x02,0x0000)
         self.i2cReg('r',0x02)
         time.sleep(0.01)
    def Temperature(self):
        try :
            self.i2c.write_byte(I2C_ADDR,0x00)
            time.sleep(0.20)
            d=[0]*2
            # print self.i2c.read_block_data(I2C_ADDR,0x00)
            d[0] = self.i2c.read_byte(I2C_ADDR) 
            time.sleep(0.001)
            d[1] = self.i2c.read_byte(I2C_ADDR) 
            time.sleep(0.001)
            #print "0x%02X :0x%02X" % (d[0],d[1])
            raw = ( d[0]<<8 | d[1] )
            #print (float(raw)/(2**16))*(165-40)
            return float(raw)/65536.0*165.0-40.0
        except IOError, err:
            print "No ACK!"
            time.sleep(0.1)
            self.Temperature()

    def Humidity(self):
        try :
            self.i2c.write_byte(I2C_ADDR,0x00)
            time.sleep(0.10)
            d=[0]*2
            d[0] = self.i2c.read_byte(I2C_ADDR) 
            time.sleep(0.001)
            d[1] = self.i2c.read_byte(I2C_ADDR) 
            time.sleep(0.001)
            #print "0x%02X :0x%02X" % (d[0],d[1])
            raw = ( d[0]<<8 | d[1] )
            return float(raw)/65536.0*100.0
        except IOError, err:
            print "No ACK!"
            time.sleep(0.1)
            self.Humidity()




    def LsbtoMsb(self,lsb,q):
         tmp = 0
         for i in range(q/2):
              tmp = tmp| ((lsb&(0x01<<i))>>i)<<(q-1-i)
         for i in range(q/2):
              tmp = tmp| ((lsb&(0x10<<i))>>i)>>(i+1)
         return tmp




# -*- coding: utf-8 -*-
# python setup.py register sdist upload
from setuptools import setup

import os
f = open(os.path.join(os.path.dirname(__file__), 'README.rst'))
long_description = f.read()
f.close()

setup(
    name = 'akilib',
    version = '2.1.3',
    url="https://github.com/nonNoise/akilib",
    keywords = ('Edison','Raspberry','IoT','akilib'),
    description = 'This Library is Hardware Library. and You can buy parts in Japan Akihabara .',
    license = 'MIT License',
    install_requires = [],
    long_description=long_description,
    packages=['akilib','akilib/edison','akilib/raspberrypi'],
    author = ' Yuta KItagami',
    author_email = 'kitagami@artifactnoise.com',
    platforms = ['Linux'],
)



 



import smbus
import time

I2C_ADDR = 0x48

class AKI_I2C_ADT7410:
    def __init__(self):
        print "AKI_I2C_ADT7410"
        self.i2c = smbus.SMBus(1)
    def Init(self):
    	conf_data = self.i2c.read_byte_data(I2C_ADDR,0x03)
    	conf_data |= 0x80 | 0x60
    	self.i2c.write_byte_data(I2C_ADDR,0x03,conf_data)
    def read(self):
    	self.i2c.write_byte_data(I2C_ADDR,0x03,0x80|0x20)
    	time.sleep(0.2)
    	reg = self.i2c.read_i2c_block_data(I2C_ADDR,0x00,2)
    	temp = ((reg[0]&0x7F)<<8)|reg[1]
    	if(reg[0]&0x80) != 0:
    		temp -=65536
    	return (temp/128.0)
   




############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################

import mraa
import time
from struct import *

class AKI_I2C_LPS25H:
    def __init__(self,port):
        print "AKI_I2C_LPS25H"
        I2C_PORT = port
        self.I2C_ADDR = 0x5C
        self.i2c = mraa.I2c(I2C_PORT)
        self.i2c.address(self.I2C_ADDR)
    def i2cReg(self,wr,addr=0x00,data=0x00):
        try:
            if(wr == "w"):
                #print "W:0x%02X = 0x%02X" % (addr,data)
                return self.i2c.writeReg(addr,data)
            elif(wr == "r"):
                tmp = self.i2c.readReg(addr)
                #print "R:0x%02X = 0x%02X" % (addr,tmp)
                return tmp
            else :
                return -1
        except IOError, err:
            print "No ACK!"
            time.sleep(0.1)
            self.i2cReg(wr,addr,data)
    def WHO_AM_I(self):
        # "WHO_AM_I"
        return self.i2cReg("r",0x0F)

    def Init(self):
        return self.i2cReg("w",0x20,0x90) 
 
    def Press(self):
        p =0
        p = p | self.i2cReg("r",0x28) <<0
        p = p | self.i2cReg("r",0x29) <<8
        p = p | self.i2cReg("r",0x2A) <<16
        mbar = p/4096.00
        return mbar

    def Temp (self):
        t = 0
        t = t | self.i2cReg("r",0x2B) <<0
        t = t | self.i2cReg("r",0x2C) <<8
        t = -((t-1)^0xffff)
        return (42.5+(t/480.0))




############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################


import mraa
import time
from struct import *



class AKI_I2C_L3GD20:
    def __init__(self,port):
        I2C_PORT = port
        self.I2C_ADDR = 0x6a
        self.i2c = mraa.I2c(I2C_PORT)
        self.i2c.address(self.I2C_ADDR)

    def i2cReg(self,wr,addr,data=0x00):
        if(wr == "w"):
            #print "W:0x%02X = 0x%02X" % (addr,data)
            return self.i2c.writeReg(addr,data)
        elif(wr == "r"):
            tmp = self.i2c.readReg(addr)
            #print "R:0x%02X = 0x%02X" % (addr,tmp)
            return tmp
        else :
            return -1
    def WhoAmI(self):
        print "Who am I?: 0x%02X" % self.i2cReg("r",0x0F)
        
    def Init(self):
        #-- Init --#
        self.i2cReg("w",0x20,0x0F)
    def X(self):
        return self.i2cReg("r",0x29)<<8 | self.i2cReg("r",0x28)
    def Y(self):
        return self.i2cReg("r",0x2B)<<8 | self.i2cReg("r",0x2A)
    def Z(self):
        return self.i2cReg("r",0x2D)<<8 | self.i2cReg("r",0x2C)









############################################################
#The MIT License (MIT)
#Copyright (c) 2015 Yuta KItagami
#Project:    https://github.com/nonNoise/akilib
############################################################


import mraa
import time
from struct import *

class AKI_I2C_HDC1000:
    def __init__(self,port):
        print "== HDC1000 Open =="      
        I2C_PORT = port
        self.i2c = mraa.I2c(I2C_PORT)
        I2C_ADDR = 0x40
        self.i2c.address(I2C_ADDR)

    def i2cReg(self,wr,addr,data=0x0000):
        if(wr == "w"):
            tmp = (data&0x00FF)<<8 | (data&0xFF00)>>8
            print "W:0x%02X = 0x%04X" % (addr,data)
            return self.i2c.writeWordReg(addr,tmp)
        elif(wr == "r"):
            tmp = self.i2c.readWordReg(addr)
            tmp = (tmp&0x00FF)<<8 | (tmp&0xFF00)>>8         
            print "R:0x%02X = 0x%04X" % (addr,tmp)
            return tmp
        else :
            return -1

    def Config(self):
        # 0 - 7 bit = 0
        # 8bit :    HRES1 = 0
        # 9bit :    HRES2 = 0 14bit mode
        # 10bit :   TRES = 0
        # 11bit :   BTST = 0 (ReadOnly)
        # 12bit :   MODE = 0
        # 13bit :   Reserved = 0
        # 14bit :   Reserved = 0
        # 15bit :   RST = 0
        self.i2cReg('r',0xFE)
        self.i2cReg('r',0xFF)
        self.i2cReg('r',0x02)
        self.i2cReg('w',0x02,0x0000)
        self.i2cReg('r',0x02)
        time.sleep(0.01)

    def Temperature(self):
        self.i2c.writeByte(0x00)
        time.sleep(0.05)
        d = self.i2c.read(2)
        #print "0x%02X :0x%02X" % (d[0],d[1])

        raw = ( d[0]<<8 | d[1] )
        #print (float(raw)/(2**16))*(165-40)
                
        return float(raw)/65536.0*165.0-40.0
    def Humidity(self):
        self.i2c.writeByte(0x00)
        time.sleep(0.05)
        d = self.i2c.read(2)
        #print "0x%02X :0x%02X" % (d[0],d[1])

        raw = ( d[0]<<8 | d[1] )

        return float(raw)/65536.0*100.0
    def LebtoMsb(self,lsb,q):
        tmp = 0
        for i in range(q/2):
            tmp = tmp| ((lsb&(0x01<<i))>>i)<<(q-1-i)
        for i in range(q/2):
            tmp = tmp| ((lsb&(0x10<<i))>>i)>>(i+1)
        return tmp

